@@ -15,17 +15,6 @@
 
 #include <KXmlGuiWindow>
 
-#ifdef KRFB_WITH_KDE_TELEPATHY
-#include <KTp/contact.h>
-#include <TelepathyQt/PendingReady>
-namespace KTp {
-    class ContactViewWidget;
-}
-namespace Tp {
-    class PendingOperation;
-}
-#endif
-
 class KLineEdit;
 
 class MainWindow : public KXmlGuiWindow
@@ -40,8 +29,8 @@ class MainWindow : public KXmlGuiWindow
         void showConfiguration();
 
     protected:
-        virtual void readProperties(const KConfigGroup & group);
-        virtual void saveProperties(KConfigGroup & group);
+        void readProperties(const KConfigGroup & group) override;
+        void saveProperties(KConfigGroup & group) override;
 
     private Q_SLOTS:
         void editPassword();
@@ -50,19 +39,11 @@ class MainWindow : public KXmlGuiWindow
         void passwordChanged(const QString&);
         void aboutConnectionAddress();
         void aboutUnattendedMode();
-#ifdef KRFB_WITH_KDE_TELEPATHY
-        void onContactDoubleClicked(const Tp::AccountPtr &, const KTp::ContactPtr &);
-        void pendingDesktopShareFinished(Tp::PendingOperation*);
-#endif
 
     private:
         Ui::MainWidget m_ui;
         bool m_passwordEditable;
         KLineEdit *m_passwordLineEdit;
-#ifdef KRFB_WITH_KDE_TELEPATHY
-        KTp::ContactViewWidget *m_contactViewWidget;
-#endif
-
 };
 
 #endif
